SuperLU: SRC/izmax1.c File Reference

SuperLU 7.0.1

Macros | Functions
izmax1.c File Reference

Finds the index of the element whose real part has maximum absolute value. More...

`#include <math.h>`
`#include "slu_dcomplex.h"`
`#include "slu_Cnames.h"`
Include dependency graph for izmax1.c:

## Macros
#define | CX(I) cx[(I)-1]

## Functions
int | izmax1_slu (int *n, doublecomplex *cx, int *incx)

## Detailed Description

Copyright (c) 2003, The Regents of the University of California, through Lawrence Berkeley National Laboratory (subject to receipt of any required approvals from U.S. Dept. of Energy)

All rights reserved.

The source code is distributed under BSD license, see the file License.txt at the top-level directory.

        -- LAPACK auxiliary routine (version 2.0) --
        Univ. of Tennessee, Univ. of California Berkeley, NAG Ltd.,
        Courant Institute, Argonne National Lab, and Rice University
        October 31, 1992

## Macro Definition Documentation

## ◆ CX

#define CX | ( |  | I | ) | cx[(I)-1]

## Function Documentation

## ◆ izmax1_slu()

int izmax1_slu | ( | int * | n,
|  | doublecomplex * | cx,
|  | int * | incx
| ) |  |

        Purpose
        =======

        IZMAX1 finds the index of the element whose real part has maximum
        absolute value.

        Based on IZAMAX from Level 1 BLAS.
        The change is to use the 'genuine' absolute value.

        Contributed by Nick Higham for use with ZLACON.

        Arguments
        =========

        N       (input) INT
                The number of elements in the vector CX.

        CX      (input) COMPLEX*16 array, dimension (N)
                The vector whose elements will be summed.

        INCX    (input) INT
                The spacing between successive values of CX.  INCX >= 1.

       =====================================================================